==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/HTTPConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HTTPConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder>{
  public HTTPConfigBuilder() {
    this(false);
  }
  public HTTPConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new HTTPConfig(), validationEnabled);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HTTPConfig(), validationEnabled);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance) {
    this(fluent, instance, false);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBasicAuth(instance.getBasicAuth()); 
    fluent.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    fluent.withProxyURL(instance.getProxyURL()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance) {
    this(instance,false);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBasicAuth(instance.getBasicAuth()); 
    this.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    this.withProxyURL(instance.getProxyURL()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig build() {
    HTTPConfig buildable = new HTTPConfig(fluent.getBasicAuth(),fluent.getBearerTokenSecret(),fluent.getProxyURL(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPConfigBuilder that = (HTTPConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/HTTPConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HTTPConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder>{
  public HTTPConfigBuilder() {
    this(false);
  }
  public HTTPConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new HTTPConfig(), validationEnabled);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HTTPConfig(), validationEnabled);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance) {
    this(fluent, instance, false);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthorization(instance.getAuthorization()); 
    fluent.withBasicAuth(instance.getBasicAuth()); 
    fluent.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    fluent.withProxyURL(instance.getProxyURL()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance) {
    this(instance,false);
  }
  public HTTPConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthorization(instance.getAuthorization()); 
    this.withBasicAuth(instance.getBasicAuth()); 
    this.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    this.withProxyURL(instance.getProxyURL()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig build() {
    HTTPConfig buildable = new HTTPConfig(fluent.getAuthorization(),fluent.getBasicAuth(),fluent.getBearerTokenSecret(),fluent.getProxyURL(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPConfigBuilder that = (HTTPConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
